@@ -103,20 +103,6 @@ sub proccall {
     return $ret;
 }
 
-sub check_itr_ar {
-    # my ( $st, $ar, $frame, $line ) = @_;
-    if ( ref($_[1]) ne 'ARRAY' ) {
-        if ( defined $_[1] ) {
-            $_[0]->error( [$_[2], $_[3]], "Iterator variables must be an ARRAY reference, not %s", neat( $_[1] ) );
-        }
-        else {
-            $_[0]->warn( [$_[2], $_[3]], "Use of nil to iterate" );
-        }
-        $_[1] = [];
-    }
-
-    return $_[1];
-}
 
 
 sub cond_ternary {
